﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace TestGalleryBinding.ViewModels
{
    public abstract class ElementsViewModelBase<T> 
        :  ElementViewModelBase where T : ElementViewModelBase
    {
        #region Private fields

        private ObservableCollection<T> _items;

        #endregion

        public ElementsViewModelBase()
        {
            _items = new ObservableCollection<T>();
        }

        public IEnumerable<T> Items
        {
            get
            {
                return _items;
            }
        }

        public bool HasItems
        {
            get
            {
                return _items.Any();
            }
        }

        public T SelectedItem
        {
            get;
            set;
        }

        public void Add(T item)
        {
            _items.Add(item);
            OnPropertyChanged("Items");
        }

        public void AddRange(IEnumerable<T> items)
        {
            foreach (var item in items)
                _items.Add(item);
            OnPropertyChanged("Items");
        }

        public bool Remove(T item)
        {
            bool result = _items.Remove(item);
            if (result)
                OnPropertyChanged("Items");
            return result;
        }

        public void RemoveAt(int index)
        {
            _items.RemoveAt(index);
            OnPropertyChanged("Items");
        }

        public void Clear()
        {
            _items.Clear();
        }
    }
}
